package com.democompany.soa.esb.service.util.customj.parammap;

import java.util.List;

/**
 * This class encapsulates the mapping of all parameters used by service to XQ
 * message parts, JMS properties, and literal values.
 * 
 * @author Leon Rubin
 */
public class ParameterMapping {
	private List<ParameterConfig> inputParameterConfigs;
	private List<ParameterConfig> outputParameterConfigs;

	/**
	 * Gets a list of input parameter configurations.
	 * 
	 * @return List of input parameter configurations
	 */
	public List<ParameterConfig> getInputParameterConfigs() {
		return inputParameterConfigs;
	}

	/**
	 * Sets a list of input parameter configurations.
	 * 
	 * @param inputParameterConfigs
	 *            List of input parameter configurations
	 */
	public void setInputParameterConfigs(
			List<ParameterConfig> inputParameterConfigs) {
		this.inputParameterConfigs = inputParameterConfigs;
	}

	/**
	 * Gets a list of output parameter configurations.
	 * 
	 * @return List of output parameter configurations
	 */
	public List<ParameterConfig> getOutputParameterConfigs() {
		return outputParameterConfigs;
	}

	/**
	 * Sets a list of output parameter configurations.
	 * 
	 * @param outputParameterConfigs
	 *            List of output parameter configurations
	 */
	public void setOutputParameterConfigs(
			List<ParameterConfig> outputParameterConfigs) {
		this.outputParameterConfigs = outputParameterConfigs;
	}

	/**
	 * Gets the output parameter configuration with a specified name.
	 * 
	 * @param parameterName
	 *            parameter name
	 * @return Parameter configuration for a parameter with that name
	 */
	public ParameterConfig getOutputParameterConfig(String parameterName) {
		ParameterConfig result = null;

		for (ParameterConfig parameterConfig : outputParameterConfigs) {
			if (parameterConfig.getName().equals(parameterName)) {
				result = parameterConfig;
				break;
			}
		}

		return result;
	}

	public String toString() {
		StringBuilder builder = new StringBuilder();

		builder.append(getClass());
		builder.append("\n{");
		builder.append("\n\n\tinputParameterConfigs\n\t{");

		for (ParameterConfig inputParameterConfig : inputParameterConfigs) {
			builder.append("\n\t\t");
			builder.append(inputParameterConfig);
		}

		builder.append("\n\n\toutputParameterConfigs\n\t{");

		for (ParameterConfig outputParameterConfig : outputParameterConfigs) {
			builder.append("\n\t\t");
			builder.append(outputParameterConfig);
		}

		builder.append("\n\t}");
		builder.append("\n}\n");

		return builder.toString();
	}
}
