package com.democompany.soa.esb.service.util.customj.parammap;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * This class encapsulates the parameters that are passed every time a service
 * is invoked. The input parameters in this object are already evaluated and
 * ready to be used by the service. A service can also set the value of output
 * parameters that this object contains.
 * 
 * @author Leon Rubin
 */
public class Parameters {
	private Map<String, Parameter> inputParameterMap;
	private Map<String, Parameter> outputParameterMap;

	/**
	 * Creates a new input/output parameter collection.
	 * 
	 */
	public Parameters() {
		inputParameterMap = new HashMap<String, Parameter>();
		outputParameterMap = new HashMap<String, Parameter>();
	}

	/**
	 * Adds an input parameter to the collection.
	 * 
	 * @param parameter
	 *            input parameter
	 */
	public void addInputParameter(Parameter parameter) {
		inputParameterMap.put(parameter.getName(), parameter);
	}

	/**
	 * Adds an output parameter to the collection.
	 * 
	 * @param parameter
	 *            output parameter
	 */
	public void addOutputParameter(Parameter parameter) {
		outputParameterMap.put(parameter.getName(), parameter);
	}

	/**
	 * Gets the input parameter with a specified name.
	 * 
	 * @param parameterName
	 *            parameter name
	 * @return Parameter with a specified name
	 */
	public Parameter getInputParameter(String parameterName) {
		return inputParameterMap.get(parameterName);
	}

	/**
	 * Gets the output parameter with a specified name.
	 * 
	 * @param parameterName
	 *            parameter name
	 * @return Parameter with a specified name
	 */
	public Parameter getOutputParameter(String parameterName) {
		return outputParameterMap.get(parameterName);
	}

	/**
	 * Gets a collection of all input parameters.
	 * 
	 * @return Collection of all input parameters
	 */
	public Collection<Parameter> getInputParameters() {
		return inputParameterMap.values();
	}

	/**
	 * Gets a collection of all output parameters.
	 * 
	 * @return Collection of all output parameters
	 */
	public Collection<Parameter> getOutputParameters() {
		return outputParameterMap.values();
	}
}
