package com.democompany.soa.esb.service.util.xml.castor;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.exolab.castor.mapping.Mapping;
import org.exolab.castor.mapping.MappingException;
import org.exolab.castor.xml.MarshalException;
import org.exolab.castor.xml.Unmarshaller;
import org.exolab.castor.xml.ValidationException;
import org.xml.sax.InputSource;

import com.democompany.soa.esb.service.util.exception.XMLException;
import com.democompany.soa.esb.service.util.xml.XMLParser;

/**
 * This class contains a method to convert XML to Java objects. This class uses
 * the Castor framework to parse the XML (see Castor mapping XML files for
 * mapping configuration details).
 * 
 * Javadoc comments for most of the methods are not provided because they will
 * be inherited from the implemented interface during generation.
 * 
 * @author Leon Rubin
 */
public class XMLParserCastorImpl implements XMLParser {
	private static Mapping mapping;

	/**
	 * Creates the parser by loading the Castor mapping file.
	 * 
	 * @throws XMLException
	 *             if an error occurs while loading a Castor mapping file
	 */
	private void init(String mappingFileName) throws XMLException {
		try {
			mapping = new Mapping();

			InputStream inputStream = XMLParserCastorImpl.class
					.getClassLoader().getResourceAsStream(mappingFileName);

			if (inputStream == null) {
				throw new XMLException("Resource " + mappingFileName
						+ " not found in classpath");
			}

			mapping.loadMapping(new InputSource(inputStream));
		} catch (IOException e) {
			e.printStackTrace();
			throw new XMLException("Failed to create mapping from file "
					+ mappingFileName, e);
		} catch (MappingException e) {
			e.printStackTrace();
			throw new XMLException("Failed to create mapping from file "
					+ mappingFileName, e);
		}
	}

	public Object parse(String file, String mappingFileName)
			throws XMLException {
		try {
			init(mappingFileName);

			Unmarshaller unmarshaller = new Unmarshaller();

			unmarshaller.setMapping(mapping);

			URL url = new URL(file);

			return unmarshaller.unmarshal(new InputSource(url.openStream()));
		} catch (MarshalException e) {
			e.printStackTrace();
			throw new XMLException("Failed t unmarshal a java object", e);
		} catch (MappingException e) {
			e.printStackTrace();
			throw new XMLException(
					"A mapping error detected while unmarshalling a java object",
					e);
		} catch (ValidationException e) {
			e.printStackTrace();
			throw new XMLException(
					"A validation error detected while unmarshalling a java object",
					e);
		} catch (IOException e) {
			e.printStackTrace();
			throw new XMLException(
					"An IO error detected while unmarshalling a java object", e);
		}
	}
}
