package com.democompany.soa.esb.service.xquery.customj.config;

/**
 * This class represents an XQuery configuration. The configuration specifies an
 * XQuery exression written in a standard FLOWR language and the name of the
 * output parameter where the result of the query should be placed.
 * 
 * @author Leon Rubin
 */
public class XQQuery {
	private String expression;
	private String outputParameterName;

	/**
	 * Gets the expression of the query. The expression may contain parameters
	 * that need to be bound to some values before the query can be executed.
	 * 
	 * @return the XQuery expression that should be executed against input XML
	 *         document(s)
	 */
	public String getExpression() {
		return expression;
	}

	/**
	 * Sets the expression.
	 * 
	 * @param expression
	 *            XQuery expression to execute
	 */
	public void setExpression(String expression) {
		this.expression = expression;
	}

	/**
	 * Gets the name of the output parameter where the query result should be
	 * written. Depending on parameter mapping, the output parameter maps to an
	 * XQPart of a JMS property.
	 * 
	 * @return String containing the name of the output parameter where the
	 *         result should be written.
	 */
	public String getOutputParameterName() {
		return outputParameterName;
	}

	/**
	 * Sets the output parameter name.
	 * 
	 * @param outputParameterName
	 *            output parameter name
	 */
	public void setOutputParameterName(String outputParameterName) {
		this.outputParameterName = outputParameterName;
	}

	public String toString() {
		return "Query {" + "expression=" + expression
				+ ", outputParameterName=" + outputParameterName + "}";
	}
}
